@@ -336,8 +336,15 @@ impl Shell {
         self.cd_stack.pop()
     }
 
+    pub fn get_current_dir(&self) -> PathBuf {
+        match self.get_str("PWD") {
+            Some(pwd) => PathBuf::from(pwd),
+            None => std::env::current_dir().unwrap_or(PathBuf::from("/"))
+        }
+    }
+
     pub fn set_current_dir(&mut self, dir: Option<PathBuf>) -> Result<()> {
-        let current = std::env::current_dir()?;
+        let current = self.get_current_dir();
         if let Some(dir) = current.to_str() {
             self.set("OLDPWD", Value::String(dir.into()), false);
         }
